import { Chain, Network } from "@wormhole-foundation/sdk-base";
import { ChainContext, Signer, TokenId, TransactionId } from "@wormhole-foundation/sdk-definitions";
import { CircleAttestationReceipt } from "../../protocols/cctpTransfer";
import { TransferQuote, TransferReceipt } from "../../types";
import { ManualRoute, StaticRouteMethods } from "../route";
import { TransferParams, ValidatedTransferParams, ValidationResult } from "../types";
export declare namespace CCTPRoute {
    type Options = {
        payload?: Uint8Array;
    };
    type NormalizedParams = {
        amount: bigint;
    };
    interface ValidatedParams extends ValidatedTransferParams<Options> {
        normalizedParams: NormalizedParams;
    }
}
type Op = CCTPRoute.Options;
type Vp = CCTPRoute.ValidatedParams;
type Tp = TransferParams<Op>;
type Vr = ValidationResult<Op>;
type Q = TransferQuote;
type R = TransferReceipt<CircleAttestationReceipt>;
export declare class CCTPRoute<N extends Network> extends ManualRoute<N, Op, R, Q> implements StaticRouteMethods<typeof CCTPRoute> {
    static meta: {
        name: string;
    };
    static supportedNetworks(): Network[];
    static supportedChains(network: Network): Chain[];
    static supportedSourceTokens(fromChain: ChainContext<Network>): Promise<TokenId[]>;
    static supportedDestinationTokens<N extends Network>(sourceToken: TokenId, fromChain: ChainContext<N>, toChain: ChainContext<N>): Promise<TokenId[]>;
    static isProtocolSupported<N extends Network>(chain: ChainContext<N>): boolean;
    getDefaultOptions(): Op;
    validate(params: Tp): Promise<Vr>;
    quote(params: Vp): Promise<TransferQuote>;
    initiate(signer: Signer, params: Vp): Promise<R>;
    complete(signer: Signer, receipt: R): Promise<TransactionId[]>;
    track(receipt: R, timeout?: number): AsyncGenerator<import("../../protocols/cctpTransfer").CircleTransferReceipt<"Solana" | "Btc" | "Algorand" | "Sui" | "Aptos" | "Near" | "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "Pythnet" | "Cosmoshub" | "Evmos" | "Injective" | "Kujira" | "Osmosis" | "Sei" | "Terra" | "Terra2" | "Wormchain" | "Xpla", "Solana" | "Btc" | "Algorand" | "Sui" | "Aptos" | "Near" | "Acala" | "Arbitrum" | "Aurora" | "Avalanche" | "Base" | "Bsc" | "Celo" | "Ethereum" | "Fantom" | "Gnosis" | "Karura" | "Klaytn" | "Moonbeam" | "Neon" | "Oasis" | "Optimism" | "Polygon" | "Rootstock" | "Sepolia" | "ArbitrumSepolia" | "BaseSepolia" | "OptimismSepolia" | "Holesky" | "Pythnet" | "Cosmoshub" | "Evmos" | "Injective" | "Kujira" | "Osmosis" | "Sei" | "Terra" | "Terra2" | "Wormchain" | "Xpla">, void, unknown>;
    private toTransferDetails;
}
export {};
//# sourceMappingURL=manual.d.ts.map